@@ -188,6 +188,19 @@ public:
     //!
     static void DumpResourceInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_INTERFACE &osInterface, MOS_RESOURCE &res, MOS_HW_COMMAND hwCmdType, uint32_t locationInCmd, uint32_t offsetInRes);
 
+    //!
+    //! \brief  Insert bindless/stateless resource state heap into OcaBufferHandlerMap
+    //! \param  [in] key
+    //!         The base address of resource state heap
+    //! \param  [in] osInterface
+    //!         Reference to PMOS_INTERFACE.
+    //! \param  [in] cmdBuffer
+    //!         Command buffer for current BB.
+    //! \return void
+    //!         No return value. Handle all exception inside the function.
+    //!
+    static void InsertResourceHeapToCurrentCmdBufferOcaBufferHandle(uint32_t *key, PMOS_INTERFACE osInterface, PMOS_COMMAND_BUFFER _cmdBuffer);
+
     //!
     //! \brief  Trace OCA Sku Value.
     //! \param  [in] cmdBuffer
