@@ -40,7 +40,6 @@
 #include <sys/types.h>
 #include <sys/sem.h>
 #include <sys/mman.h>
-#include "mos_compat.h" // libc variative definitions: backtrace
 #include "mos_user_setting.h"
 #include "mos_utilities_specific.h"
 #include "mos_utilities.h"
@@ -67,8 +66,6 @@ int32_t g_mosMemoryFailSimulateAllocCounter = 0;
 int32_t *MosUtilities::m_mosAllocMemoryFailSimulateAllocCounter = &g_mosMemoryFailSimulateAllocCounter;
 #endif
 
-static bool s_skipToReportReg = false;
-
 double MosUtilities::MosGetTime()
 {
     struct timespec ts = {};
@@ -1552,14 +1549,6 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
         if (regStream.good())
         {
             std::string id       = "";
-
-            static const char *disableReportRegKeyList[] = {
-#if (_DEBUG || _RELEASE_INTERNAL)
-                __MEDIA_USER_FEATURE_VALUE_ENABLE_MEDIA_CCS,
-#endif
-                "INTEL MEDIA ALLOC MODE"
-            };
-            static const uint32_t disableReportRegKeyListCount = sizeof(disableReportRegKeyList) / sizeof(disableReportRegKeyList[0]);
             while(!regStream.eof())
             {
                 std::string line = "";
@@ -1598,17 +1587,6 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
                         {
                             auto &keys = regBufferMap[id];
                             keys[name] = value;
-                            if (s_skipToReportReg == false && id == USER_SETTING_CONFIG_PATH)
-                            {
-                                for (uint32_t i = 0; i < disableReportRegKeyListCount; i++)
-                                {
-                                    if (strcmp(name.c_str(), disableReportRegKeyList[i]) == 0)
-                                    {
-                                        s_skipToReportReg = true;
-                                        break;
-                                    }
-                                }
-                            }
                         }
                     }
                 }
@@ -1630,11 +1608,6 @@ MOS_STATUS MosUtilities::MosUninitializeReg(RegBufferMap &regBufferMap)
 {
     MOS_STATUS status = MOS_STATUS_SUCCESS;
 
-    if (s_skipToReportReg)
-    {
-        return MOS_STATUS_SUCCESS;
-    }
-
     if (regBufferMap.size() == 0)
     {
         return MOS_STATUS_SUCCESS;
@@ -1660,7 +1633,7 @@ MOS_STATUS MosUtilities::MosUninitializeReg(RegBufferMap &regBufferMap)
         if (regFile.good())
         {
             regFile.close();
-            regStream.open(USER_FEATURE_FILE_NEXT, std::ios::out | std::ios::trunc);
+            regStream.open(USER_FEATURE_FILE_REPORT, std::ios::out | std::ios::trunc);
         }
         else
         {
@@ -1668,24 +1641,21 @@ MOS_STATUS MosUtilities::MosUninitializeReg(RegBufferMap &regBufferMap)
             return status;
         }
 #else
-        regStream.open(USER_FEATURE_FILE_NEXT, std::ios::out | std::ios::trunc);
+        regStream.open(USER_FEATURE_FILE_REPORT, std::ios::out | std::ios::trunc);
 #endif
         if (regStream.good())
         {
-            for(auto pair: regBufferMap)
+            regStream << iter->first << "\n";
+
+            auto &keys = iter->second;
+            for (auto key: keys)
             {
-                regStream << pair.first << "\n";
-
-                auto &keys = regBufferMap[pair.first];
-                for (auto key: keys)
-                {
-                    auto name = key.first;
-                    regStream << key.first << "=" << key.second << "\n";
-                }
-
-                keys.clear();
-                regStream << std::endl;
+                auto name = key.first;
+                regStream << key.first << "=" << key.second << "\n";
             }
+
+            keys.clear();
+            regStream << std::endl;
             regBufferMap.clear();
             regStream.flush();
         }
@@ -2494,7 +2464,7 @@ void MosUtilities::MosTraceEventInit()
             MosUtilitiesSpecificNext::m_levelEnv = static_cast<uint32_t>(strtoll(val, nullptr, 0));
         }
         m_mosTraceEnable = true;
-        m_mosTraceFilter = &MosUtilitiesSpecificNext::m_filterEnv;
+        m_mosTraceFilter = { &MosUtilitiesSpecificNext::m_filterEnv, 1};
         m_mosTraceLevel  = reinterpret_cast<uint8_t *>(&MosUtilitiesSpecificNext::m_levelEnv);
     }
     else
